==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_kanpa_house.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

--去外面
function Door_GoVillage()
    if(FLJ("Night")) then
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village_night","E0090",51,10)
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",51,10)
    end
end

--调查罐子
function Pot()
    PRI()
    MS3("\n*向罐子里看了一眼")NOD()CLR()
    CAT("食物都没了嘛...")NOD()
    CAT("\n他也太能吃了，")NOD()
    CAT("\n居然一点也没给我留下。")NOD()
end

--间八钓鱼回到家发现马宾不在
function KanpaBackHome()
    KEY()
    FAI(0)
    WAI(32)
    MS3("\n马宾！我钓鱼回来了")NOD()
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    SNP("CS_mychar_kanpa_animate",14,14,1,"mainLayer","Kanpa1")--间八出现
    ANP("Kanpa1",200,0)--显示鱼竿
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    WAI(32)
    CLO()
    --走到桌子附近
    ANP("Kanpa1",1,1)--走路
    WAI(6*16)--走6格
    ANP("Kanpa1",0,1)--停止
    WAI(16)
    --转头看
    ANP("Kanpa1",0,0)--停止
    WAI(32)
    ANP("Kanpa1",0,1)--停止
    WAI(32)
    MS3("马宾？")NOD()
    CAT("\n不在家嘛...")NOD()
    CAT("\n去找多隆子她们问一下吧。")NOD()
    --水桶在地图上出现
    FLP("KanpaFishingBack")
    FLP("GoTorokoHome")
    --玩家可以控制间八
    MOV(20,14)
    SMC()
    DNP("Kanpa1")
    AMC("show_fishing_rod","CS_mychar_kanpa");--显示鱼竿
    SLR(1)
end

function Bed()
    if(FLJ("AskedJack")) then
        PRI()MM0()
        FAO(0)TRA("CS_king_house","ThreeDaysLater",20,15)
    else
        KEY()
        MS4("\n要休息吗？")YNJ()
        if(YES()) then
            FAO(4)CMU("XXXX")WAI(20)CLR()
            MS4("\n...")NOD()CLO()
            WAI(50)
            LIP(1000)
            SOU("CS_020_health_refill")
            AMC(0,1,PLY())
            MS4("\n体力得到了回复。")NOD()CLO()
            RMU()FAI(4)
        end
    end
end


function SueAndTorokoVisitKanpa()
    KEY()CMU("CS_Mura")FAI(0)
    WAI(64)
    MS3("\n间八！我们来了")NOD()CLO()
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    SNP("CS_sue_animate",14,14,1,"mainLayer","Sue1")--数出现
    ANP("Sue1","normal",1)
    WAI(16)
    --数往前走
    ANP("Sue1","walk")
    WAI(3*16)
    SNP("CS_toroko_animate",14,14,1,"mainLayer","Toroko1")--多隆子出现
    ANP("Toroko1","normal",1)
    WAI(16)
    ANP("Toroko1","walk")
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    WAI(16)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Toroko1","normal",1)
    WAI(32)
    --数转身
    ANP("Sue1","normal",0)
    WAI(16)
    ANP("Sue1","back",0)
    WAI(32)
    FAC("sue_sad")MS3("\n他好像不在家...")NOD()CLR()
    FAC("toroko_><")CAT("\n也许在酒吧吧~")ANP("Sue1","normal",0)NOD()CLR()
    FAC("sue_normal")MS3("也对！")NOD()
    ANP("Sue1","angry")
    FAC("sue_angry")MS3("\n那我们一起去酒吧找他吧~")NOD()CLR()
    FAC("toroko_><")MS3("\n诶？！")NOD()CAT("那种地方我们能去嘛？")NOD()CLR()
    ANP("Sue1","normal",0)
    FAC("sue_normal")MS3("反正金不在")NOD()
    CAT("\n杰克那个胆小鬼也不会拿我们怎么样~")NOD()CLR()
    ANP("Sue1","angry")
    FAC("sue_angry")CAT("\n就这么决定了！")NOD()CLO()
    ANP("Sue1","walk")
    WAI(2*16)
    ANP("Toroko1","normal",0)
    WAI(3*16)
    ANP("Sue1","normal")
    WAI(16)
    ANP("Sue1","back")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    WAI(16)
    DNP("Sue1")
    WAI(32)
    FAC("toroko_><")MS3("\n数姐姐等下我！")NOD()CLO()
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(54)
    DNP("Toroko1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    FAO(2)
    TRA("CS_king_house","JackWaitKanpa",14,15)
end

==> ocstore25_12_22.zip: OcStore/Prgm/data/map/CS_kanpa_house.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

--去外面
function Door_GoVillage()
    if(FLJ("Night")) then
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village_night","E0090",51,10)
    else
        PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",51,10)
    end
end

--调查罐子
function Pot()
    PRI()
    MS3("\n*向罐子里看了一眼")NOD()CLR()
    CAT("食物都没了嘛...")NOD()
    CAT("\n他也太能吃了，")NOD()
    CAT("\n居然一点也没给我留下。")NOD()
end

--间八钓鱼回到家发现马宾不在
function KanpaBackHome()
    KEY()
    FAI(0)
    WAI(32)
    MS3("\n马宾！我钓鱼回来了~")NOD()
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    SNP("CS_mychar_kanpa_animate",14,14,1,"mainLayer","Kanpa1")--间八出现
    ANP("Kanpa1",200,0)--显示鱼竿
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    WAI(32)
    CLO()
    --走到桌子附近
    ANP("Kanpa1",1,1)--走路
    WAI(6*16)--走6格
    ANP("Kanpa1",0,1)--停止
    WAI(16)
    --转头看
    ANP("Kanpa1",0,0)--停止
    WAI(32)
    ANP("Kanpa1",0,1)--停止
    WAI(32)
    MS3("马宾？")NOD()
    CAT("\n不在家嘛...")NOD()
    CAT("\n去找多隆子她们问一下吧。")NOD()
    --水桶在地图上出现
    FLP("KanpaFishingBack")
    FLP("GoTorokoHome")
    --玩家可以控制间八
    MOV(20,14)
    SMC()
    DNP("Kanpa1")
     --如果是双玩家模式
     if(GOP() == 2) then
        P2A(false)--禁止玩家2使用AI切换
    end
    AMC("show_fishing_rod","CS_mychar_kanpa");--显示鱼竿
    SLR(1)
end

function Bed()
    if(FLJ("AskedJack")) then
        PRI()MM0()
        FAO(0)TRA("CS_king_house","ThreeDaysLater",20,15)
    else
        KEY()
        MS4("\n要休息吗？")YNJ()
        if(YES()) then
            FAO(4)CMU("XXXX")WAI(20)CLR()
            MS4("\n...")NOD()CLO()
            WAI(50)
            LIP(1000)
            SOU("CS_020_health_refill")
            AMC(0,1,PLY())
            MS4("\n体力得到了回复。")NOD()CLO()
            RMU()FAI(4)
        end
    end
end


function SueAndTorokoVisitKanpa()
    KEY()CMU("CS_Mura")FAI(0)
    WAI(64)
    MS3("\n间八！我们来了")NOD()CLO()
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    SNP("CS_sue_animate",14,14,1,"mainLayer","Sue1")--数出现
    ANP("Sue1","normal",1)
    WAI(16)
    --数往前走
    ANP("Sue1","walk")
    WAI(3*16)
    SNP("CS_toroko_animate",14,14,1,"mainLayer","Toroko1")--多隆子出现
    ANP("Toroko1","normal",1)
    WAI(16)
    ANP("Toroko1","walk")
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    WAI(16)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Toroko1","normal",1)
    WAI(32)
    --数转身
    ANP("Sue1","normal",0)
    WAI(16)
    ANP("Sue1","back",0)
    WAI(32)
    FAC("sue_sad")MS3("\n他好像不在家...")NOD()CLR()
    FAC("toroko_><")CAT("\n也许在酒吧吧~")ANP("Sue1","normal",0)NOD()CLR()
    FAC("sue_normal")MS3("也对！")NOD()
    ANP("Sue1","angry")
    FAC("sue_angry")MS3("\n那我们一起去酒吧找他吧~")NOD()CLR()
    FAC("toroko_><")MS3("\n诶？！")NOD()CAT("那种地方我们能去嘛？")NOD()CLR()
    ANP("Sue1","normal",0)
    FAC("sue_normal")MS3("反正金不在")NOD()
    CAT("\n杰克那个胆小鬼也不会拿我们怎么样~")NOD()CLR()
    ANP("Sue1","angry")
    FAC("sue_angry")CAT("\n就这么决定了！")NOD()CLO()
    ANP("Sue1","walk")
    WAI(2*16)
    ANP("Toroko1","normal",0)
    WAI(3*16)
    ANP("Sue1","normal")
    WAI(16)
    ANP("Sue1","back")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)--开门
    WAI(16)
    DNP("Sue1")
    WAI(32)
    FAC("toroko_><")MS3("\n数姐姐等下我！")NOD()CLO()
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(54)
    DNP("Toroko1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)--关门
    FAO(2)
    TRA("CS_king_house","JackWaitKanpa",14,15)
end
